summaryrefslogtreecommitdiffstats
path: root/kig/kig/kig_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kig/kig/kig_part.cpp')
-rw-r--r--kig/kig/kig_part.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kig/kig/kig_part.cpp b/kig/kig/kig_part.cpp
index ef7fa470..3e85d0b4 100644
--- a/kig/kig/kig_part.cpp
+++ b/kig/kig/kig_part.cpp
@@ -83,17 +83,17 @@ TDEAboutData* KigPart::createAboutData()
}
class SetCoordinateSystemAction
- : public KSelectAction
+ : public TDESelectAction
{
KigPart& md;
public:
- SetCoordinateSystemAction( KigPart& d, KActionCollection* parent );
+ SetCoordinateSystemAction( KigPart& d, TDEActionCollection* parent );
void slotActivated( int index );
};
SetCoordinateSystemAction::SetCoordinateSystemAction(
- KigPart& d, KActionCollection* parent )
- : KSelectAction( i18n( "&Set Coordinate System" ), 0, parent, "settings_set_coordinate_system" ),
+ KigPart& d, TDEActionCollection* parent )
+ : TDESelectAction( i18n( "&Set Coordinate System" ), 0, parent, "settings_set_coordinate_system" ),
md( d )
{
setItems( CoordinateSystemFactory::names() );
@@ -218,7 +218,7 @@ void KigPart::setupActions()
this, TQT_SLOT( slotSelectAll() ), actionCollection() );
aDeselectAll = KStdAction::deselect(
this, TQT_SLOT( slotDeselectAll() ), actionCollection() );
- aInvertSelection = new KAction(
+ aInvertSelection = new TDEAction(
i18n( "Invert Selection" ), "", 0, this,
TQT_SLOT( slotInvertSelection() ), actionCollection(),
"edit_invert_selection" );
@@ -227,30 +227,30 @@ void KigPart::setupActions()
KIconLoader* l = instance()->iconLoader();
TQPixmap tmp;
- aDeleteObjects = new KAction(
+ aDeleteObjects = new TDEAction(
i18n("&Delete Objects"), "editdelete", Key_Delete, this,
TQT_SLOT(deleteObjects()), actionCollection(), "delete_objects");
aDeleteObjects->setToolTip(i18n("Delete the selected objects"));
- aCancelConstruction = new KAction(
+ aCancelConstruction = new TDEAction(
i18n("Cancel Construction"), "stop", Key_Escape, this,
TQT_SLOT(cancelConstruction()), actionCollection(), "cancel_construction");
aCancelConstruction->setToolTip(
i18n("Cancel the construction of the object being constructed"));
aCancelConstruction->setEnabled(false);
- aShowHidden = new KAction(
+ aShowHidden = new TDEAction(
i18n("U&nhide All"), 0, this, TQT_SLOT( showHidden() ),
actionCollection(), "edit_unhide_all");
aShowHidden->setToolTip(i18n("Show all hidden objects"));
aShowHidden->setEnabled( true );
- aNewMacro = new KAction(
+ aNewMacro = new TDEAction(
i18n("&New Macro..."), "gear", 0, this, TQT_SLOT(newMacro()),
actionCollection(), "macro_action");
aNewMacro->setToolTip(i18n("Define a new macro"));
- aConfigureTypes = new KAction(
+ aConfigureTypes = new TDEAction(
i18n("Manage &Types..."), 0, this, TQT_SLOT(editTypes()),
actionCollection(), "types_edit");
aConfigureTypes->setToolTip(i18n("Manage macro types."));
@@ -258,7 +258,7 @@ void KigPart::setupActions()
KigExportManager::instance()->addMenuAction( this, m_widget->realWidget(),
actionCollection() );
- KAction* a = KStdAction::zoomIn( TQT_TQOBJECT(m_widget), TQT_SLOT( slotZoomIn() ),
+ TDEAction* a = KStdAction::zoomIn( TQT_TQOBJECT(m_widget), TQT_SLOT( slotZoomIn() ),
actionCollection() );
a->setToolTip( i18n( "Zoom in on the document" ) );
a->setWhatsThis( i18n( "Zoom in on the document" ) );
@@ -284,7 +284,7 @@ void KigPart::setupActions()
a = KStdAction::fullScreen( TQT_TQOBJECT(m_widget), TQT_SLOT( toggleFullScreen() ), actionCollection(), (TQWidget*)(widget()->parent()),"fullscreen" );
#else
tmp = l->loadIcon( "window_fullscreen", KIcon::Toolbar );
- a = new KAction(
+ a = new TDEAction(
i18n( "Full Screen" ), tmp, CTRL+SHIFT+Key_F,
m_widget, TQT_SLOT( toggleFullScreen() ),
actionCollection(), "fullscreen" );
@@ -293,37 +293,37 @@ void KigPart::setupActions()
a->setWhatsThis( i18n( "View this document full-screen." ) );
// TODO: an icon for this..
- a = new KAction(
+ a = new TDEAction(
i18n( "&Select Shown Area" ), "viewmagfit", 0, TQT_TQOBJECT(m_widget), TQT_SLOT( zoomRect() ),
actionCollection(), "view_select_shown_rect" );
a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
- a = new KAction(
+ a = new TDEAction(
i18n( "S&elect Zoom Area" ), "viewmag", 0, TQT_TQOBJECT(m_widget), TQT_SLOT( zoomArea() ),
actionCollection(), "view_zoom_area" );
// a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
// a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
- aToggleGrid = new KToggleAction(
+ aToggleGrid = new TDEToggleAction(
i18n( "Show &Grid" ), 0, this, TQT_SLOT( toggleGrid() ),
actionCollection(), "settings_show_grid" );
aToggleGrid->setToolTip( i18n( "Show or hide the grid." ) );
aToggleGrid->setChecked( true );
- aToggleAxes = new KToggleAction(
+ aToggleAxes = new TDEToggleAction(
i18n( "Show &Axes" ), 0, this, TQT_SLOT( toggleAxes() ),
actionCollection(), "settings_show_axes" );
aToggleAxes->setToolTip( i18n( "Show or hide the axes." ) );
aToggleAxes->setChecked( true );
- aToggleNightVision = new KToggleAction(
+ aToggleNightVision = new TDEToggleAction(
i18n( "Wear Infrared Glasses" ), 0, this, TQT_SLOT( toggleNightVision() ),
actionCollection(), "settings_toggle_nightvision" );
aToggleNightVision->setToolTip( i18n( "Enable/Disable hidden objects visibility." ) );
aToggleNightVision->setChecked( false );
// select coordinate system KActionMenu..
aCoordSystem = new SetCoordinateSystemAction( *this, actionCollection() );
}
@@ -563,7 +563,7 @@ void KigPart::delObjects( const std::vector<ObjectHolder*>& os )
void KigPart::enableConstructActions( bool enabled )
{
for_each( aActions.begin(), aActions.end(),
- bind2nd( mem_fun( &KAction::setEnabled ),
+ bind2nd( mem_fun( &TDEAction::setEnabled ),
enabled ) );
}
@@ -293,37 +293,37 @@ void KigPart::setupActions()
aToggleNightVision->setToolTip( i18n( "Enable/Disable hidden objects visibility." ) );
aToggleNightVision->setChecked( false );
- // select coordinate system KActionMenu..
+ // select coordinate system TDEActionMenu..
aCoordSystem = new SetCoordinateSystemAction( *this, actionCollection() );
}